==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/RulesEngineMatchVariable.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Match Variable
 */
public enum class RulesEngineMatchVariable(
    public val javaValue: com.pulumi.azurenative.network.enums.RulesEngineMatchVariable,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.RulesEngineMatchVariable> {
    IsMobile(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.IsMobile),
    RemoteAddr(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RemoteAddr),
    RequestMethod(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestMethod),
    QueryString(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.QueryString),
    PostArgs(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.PostArgs),
    RequestUri(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestUri),
    RequestPath(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestPath),
    RequestFilename(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestFilename),
    RequestFilenameExtension(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestFilenameExtension),
    RequestHeader(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestHeader),
    RequestBody(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestBody),
    RequestScheme(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestScheme),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.RulesEngineMatchVariable = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.RulesEngineMatchVariable):
            RulesEngineMatchVariable =
            RulesEngineMatchVariable.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/RulesEngineMatchVariable.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Match Variable
 */
public enum class RulesEngineMatchVariable(
    public val javaValue: com.pulumi.azurenative.network.enums.RulesEngineMatchVariable,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.RulesEngineMatchVariable> {
    IsMobile(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.IsMobile),
    RemoteAddr(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RemoteAddr),
    RequestMethod(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestMethod),
    QueryString(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.QueryString),
    PostArgs(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.PostArgs),
    RequestUri(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestUri),
    RequestPath(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestPath),
    RequestFilename(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestFilename),
    RequestFilenameExtension(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestFilenameExtension),
    RequestHeader(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestHeader),
    RequestBody(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestBody),
    RequestScheme(com.pulumi.azurenative.network.enums.RulesEngineMatchVariable.RequestScheme),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.RulesEngineMatchVariable = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.RulesEngineMatchVariable): RulesEngineMatchVariable =
            RulesEngineMatchVariable.values().first { it.javaValue == javaType }
    }
}
